var x = /*#__PURE__*/function () {
  "use strict";

  var _proto = x.prototype;

  _proto.f = function f() {
    1;
    2;
    3;
  };

  function x() {
    4;
    5;
    6;
  }

  return x;
}();
